@@ -1,77 +1,40 @@
-# Copyrights 2003-2021 by [Mark Overmeer].
-#  For other contributors see ChangeLog.
-# See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.02.
-# This code is part of perl distribution OODoc.  It is licensed under the
-# same terms as Perl itself: https://spdx.org/licenses/Artistic-2.0.html
+# This code is part of Perl distribution OODoc version 3.00.
+# The POD got stripped from this file by OODoc version 3.00.
+# For contributors see file ChangeLog.
 
-package OODoc::Parser::Markov;
-use vars '$VERSION';
-$VERSION = '2.02';
+# This software is copyright (c) 2003-2025 by Mark Overmeer.
 
-use base 'OODoc::Parser';
+# This is free software; you can redistribute it and/or modify it under
+# the same terms as the Perl 5 programming language system itself.
+# SPDX-License-Identifier: Artistic-1.0-Perl OR GPL-1.0-or-later
+
+package OODoc::Parser::Markov;{
+our $VERSION = '3.00';
+}
+
+use parent 'OODoc::Parser';
 
 use strict;
 use warnings;
 
 use Log::Report    'oodoc';
 
-use OODoc::Text::Chapter;
-use OODoc::Text::Section;
-use OODoc::Text::SubSection;
-use OODoc::Text::SubSubSection;
-use OODoc::Text::Subroutine;
-use OODoc::Text::Option;
-use OODoc::Text::Default;
-use OODoc::Text::Diagnostic;
-use OODoc::Text::Example;
-use OODoc::Manual;
+use OODoc::Text::Chapter       ();
+use OODoc::Text::Section       ();
+use OODoc::Text::SubSection    ();
+use OODoc::Text::SubSubSection ();
+use OODoc::Text::Subroutine    ();
+use OODoc::Text::Option        ();
+use OODoc::Text::Default       ();
+use OODoc::Text::Diagnostic    ();
+use OODoc::Text::Example       ();
+use OODoc::Manual              ();
 
 use File::Spec;
-use IO::File;
 
 my $url_modsearch = "http://search.cpan.org/perldoc?";
 my $url_coderoot  = 'CODE';
-
-
-#-------------------------------------------
-
-my @default_rules =
- ( [ '=cut'        => 'docCut'        ]
- , [ '=chapter'    => 'docChapter'    ]
- , [ '=section'    => 'docSection'    ]
- , [ '=subsection' => 'docSubSection' ]
- , [ '=subsubsection' => 'docSubSubSection' ]
- , [ '=method'     => 'docSubroutine' ]
- , [ '=i_method'   => 'docSubroutine' ]
- , [ '=c_method'   => 'docSubroutine' ]
- , [ '=ci_method'  => 'docSubroutine' ]
- , [ '=function'   => 'docSubroutine' ]
- , [ '=tie'        => 'docSubroutine' ]
- , [ '=overload'   => 'docSubroutine' ]
- , [ '=option'     => 'docOption'     ]
- , [ '=default'    => 'docDefault'    ]
- , [ '=requires'   => 'docRequires'   ]
- , [ '=example'    => 'docExample'    ]
- , [ '=examples'   => 'docExample'    ]
- , [ '=error'      => 'docDiagnostic' ]
- , [ '=warning'    => 'docDiagnostic' ]
- , [ '=notice'     => 'docDiagnostic' ]
- , [ '=debug'      => 'docDiagnostic' ]
-
- # deprecated
- , [ '=head1'      => 'docChapter'    ]
- , [ '=head2'      => 'docSection'    ]
- , [ '=head3'      => 'docSubSection' ]
-
- # problem spotter
- , [ qr/^(warn|die|carp|confess|croak)\s/ => 'debugRemains' ]
- , [ qr/^( sub \s+ \w
-         | (?:my|our) \s+ [\($@%]
-         | (?:package|use) \s+ \w+\:
-         )
-       /x => 'forgotCut' ]
- );
+my @default_rules;
 
 
 sub init($)
@@ -82,27 +45,80 @@ sub init($)
     unshift @rules, @{delete $args->{additional_rules}}
         if exists $args->{additional_rules};
 
-    $self->{OP_rules} = [];
+    $self->{OPM_rules} = [];
     $self->rule(@$_) for @rules;
     $self;
 }
 
+#------------------
+
+sub setBlock($)
+{   my ($self, $ref) = @_;
+    $self->{OPM_block} = $ref;
+    $self->inDoc(1);
+    $self;
+}
+
+
+sub inDoc(;$) { my $s = shift; @_ ? $s->{OPM_in_pod} = shift : $s->{OPM_in_pod} }
+
+
+sub currentManual(;$) { my $s = shift; @_ ? ($s->{OPM_manual} = shift) : $s->{OPM_manual} }
+
+
+sub rules() { $_[0]->{OPM_rules} }
+
 #-------------------------------------------
 
+@default_rules =
+  ( [ '=cut'        => 'docCut'        ]
+  , [ '=chapter'    => 'docChapter'    ]
+  , [ '=section'    => 'docSection'    ]
+  , [ '=subsection' => 'docSubSection' ]
+  , [ '=subsubsection' => 'docSubSubSection' ]
+  , [ '=method'     => 'docSubroutine' ]
+  , [ '=i_method'   => 'docSubroutine' ]
+  , [ '=c_method'   => 'docSubroutine' ]
+  , [ '=ci_method'  => 'docSubroutine' ]
+  , [ '=function'   => 'docSubroutine' ]
+  , [ '=tie'        => 'docSubroutine' ]
+  , [ '=overload'   => 'docSubroutine' ]
+  , [ '=option'     => 'docOption'     ]
+  , [ '=default'    => 'docDefault'    ]
+  , [ '=requires'   => 'docRequires'   ]
+  , [ '=example'    => 'docExample'    ]
+  , [ '=examples'   => 'docExample'    ]
+  , [ '=error'      => 'docDiagnostic' ]
+  , [ '=warning'    => 'docDiagnostic' ]
+  , [ '=notice'     => 'docDiagnostic' ]
+  , [ '=debug'      => 'docDiagnostic' ]
+ 
+  # deprecated
+  , [ '=head1'      => 'docChapter'    ]
+  , [ '=head2'      => 'docSection'    ]
+  , [ '=head3'      => 'docSubSection' ]
+ 
+  # problem spotter
+  , [ qr/^(warn|die|carp|confess|croak)\s/ => 'debugRemains' ]
+  , [ qr/^( sub \s+ \w
+          | (?:my|our) \s+ [\($@%]
+          | (?:package|use) \s+ \w+\:
+          )
+        /x => 'forgotCut' ]
+  );
+
 
 sub rule($$)
 {   my ($self, $match, $action) = @_;
-    push @{$self->{OP_rules}}, [$match, $action];
+    push @{$self->rules}, [$match, $action];
     $self;
 }
 
-#-------------------------------------------
-
 
 sub findMatchingRule($)
 {   my ($self, $line) = @_;
 
-    foreach ( @{$self->{OP_rules}} )
+    foreach ( @{$self->rules} )
     {   my ($match, $action) = @$_;
         if(ref $match)
         {   return ($&, $action) if $line =~ $match;
@@ -126,11 +142,11 @@ sub parse(@)
     my $version = $args{version}      or panic;
     my $distr   = $args{distribution} or panic;
 
-    my $in     = IO::File->new($input, 'r')
-       or die "ERROR: cannot read document from $input: $!\n";
+    open my $in, '<:encoding(utf8)', $input
+        or fault __x"cannot read document from {file}", file => $input;
 
-    my $out    = IO::File->new($output, 'w')
-       or die "ERROR: cannot write stripped code to $output: $!\n";
+    open my $out, '>:encoding(utf8)', $output
+        or fault __x"cannot write stripped code to {file}", file => $output;
 
     # pure doc files have no package statement included, so it shall
     # be created beforehand.
@@ -140,14 +156,14 @@ sub parse(@)
     my $pure_pod = $input =~ m/\.pod$/;
     if($pure_pod)
     {   $manual = OODoc::Manual->new
-         ( package  => $self->filenameToPackage($input)
-         , pure_pod => 1
-         , source   => $input
-         , parser   => $self
+          ( package  => $self->filenameToPackage($input)
+          , pure_pod => 1
+          , source   => $input
+          , parser   => $self
 
-         , distribution => $distr
-         , version      => $version
-         );
+          , distribution => $distr
+          , version      => $version
+          );
 
         push @manuals, $manual;
         $self->currentManual($manual);
@@ -170,55 +186,46 @@ sub parse(@)
         {   $out->print($1);
             my $package = $2;
 
-            # I would like to use 'our' here, but in some cases, that will
-            # cause compaints about double declaration with our.
-            $out->print("\nuse vars '\$VERSION';\n\$VERSION = '$version';\n");
+            # Wrap VERSION declaration in a block to avoid any problems with
+            # double declaration
+            $out->print("{\nour \$VERSION = '$version';\n}\n");
             $out->print($line);
 
             $manual = OODoc::Manual->new
-             ( package  => $package
-             , source   => $input
-             , stripped => $output
-             , parser   => $self
+              ( package  => $package
+              , source   => $input
+              , stripped => $output
+              , parser   => $self
 
-             , distribution => $distr
-             , version      => $version
-             );
+              , distribution => $distr
+              , version      => $version
+              );
             push @manuals, $manual;
             $self->currentManual($manual);
         }
         elsif(!$self->inDoc && $line =~ m/^=package\s*([\w\-\:]+)\s*$/)
         {   my $package = $1;
             $manual = OODoc::Manual->new
-             ( package  => $package
-             , source   => $input
-             , stripped => $output
-             , parser   => $self
-             , distribution => $distr
-             , version      => $version
-             );
+              ( package  => $package
+              , source   => $input
+              , stripped => $output
+              , parser   => $self
+              , distribution => $distr
+              , version      => $version
+              );
             push @manuals, $manual;
             $self->currentManual($manual);
         }
         elsif(my($match, $action) = $self->findMatchingRule($line))
-        {
-
-            if(ref $action)
-            {   $action->($self, $match, $line, $input, $ln)
-                  or $out->print($line);
-            }
-            else
-            {   no strict 'refs';
-                $self->$action($match, $line, $input, $ln)
-                  or $out->print($line);
-            }
+        {   $self->$action($match, $line, $input, $ln)
+                or $out->print($line);
         }
         elsif($line =~ m/^=(over|back|item|for|pod|begin|end|head4|encoding)\b/)
         {   ${$self->{OPM_block}} .= "\n". $line;
             $self->inDoc(1);
         }
         elsif(substr($line, 0, 1) eq '=')
-        {   warn "WARNING: unknown markup in $input line $ln:\n $line";
+        {   warning __x"unknown markup in {file} line {linenr}:\n {line}", file => $input, linenr => $ln, line => $line;
             ${$self->{OPM_block}} .= $line;
             $self->inDoc(1);
         }
@@ -226,7 +233,7 @@ sub parse(@)
         {   # add the line to the currently open text block
             my $block = $self->{OPM_block};
             unless($block)
-            {   warn "WARNING: no block for line $ln in file $input\n $line";
+            {   warning __x"no block for line {linenr} in file {file}\n {line}", file => $input, linenr => $ln, line => $line;
                 my $dummy = '';
                 $block = $self->setBlock(\$dummy);
             }
@@ -240,8 +247,8 @@ sub parse(@)
         }
     }
 
-    warn "WARNING: doc did not end in $input.\n"
-        if $self->inDoc && ! $pure_pod;
+    ! $self->inDoc || $pure_pod
+        or warning __x"doc did not end in {file}", file => $input;
 
     $self->closeChapter;
     $in->close && $out->close;
@@ -249,35 +256,6 @@ sub parse(@)
     @manuals;
 }
 
-#-------------------------------------------
-
-
-sub setBlock($)
-{   my ($self, $ref) = @_;
-    $self->{OPM_block} = $ref;
-    $self->inDoc(1);
-    $self;
-}
-
-#-------------------------------------------
-
-
-sub inDoc(;$)
-{   my $self = shift;
-    $self->{OPM_in_pod} = shift if @_;
-    $self->{OPM_in_pod};
-}
-
-#-------------------------------------------
-
-
-sub currentManual(;$)
-{   my $self = shift;
-    @_ ? $self->{OPM_manual} = shift : $self->{OPM_manual};
-}
-
-#-------------------------------------------
-
 
 sub docCut($$$$)
 {   my ($self, $match, $line, $fn, $ln) = @_;
@@ -287,8 +265,8 @@ sub docCut($$$$)
         return;
     }
 
-    warn "WARNING: $match does not terminate any doc in $fn line $ln.\n"
-        unless $self->inDoc;
+    $self->inDoc
+        or warning __x"Pod tag {tag} does not terminate any doc in {file} line {line}", tag => $match, file => $fn, line => $ln;
 
     $self->inDoc(0);
     1;
@@ -305,15 +283,11 @@ sub docChapter($$$$)
 
     $self->closeChapter;
 
-    my $manual = $self->currentManual;
-    die "ERROR: chapter $line before package statement in $fn line $ln\n"
-       unless defined $manual;
+    my $manual = $self->currentManual
+        or error __x"chapter {name} before package statement in {file} line {line}", name => $line, file => $fn, line => $ln;
 
-    my $chapter = $self->{OPM_chapter} = OODoc::Text::Chapter->new
-     ( name    => $line
-     , manual  => $manual
-     , linenr  => $ln
-     );
+    my $chapter = $self->{OPM_chapter} =
+        OODoc::Text::Chapter->new(name => $line, manual => $manual, linenr => $ln);
 
     $self->setBlock($chapter->openDescription);
     $manual->chapter($chapter);
@@ -337,15 +311,11 @@ sub docSection($$$$)
 
     $self->closeSection;
 
-    my $chapter = $self->{OPM_chapter};
-    die "ERROR: section `$line' outside chapter in $fn line $ln\n"
-       unless defined $chapter;
+    my $chapter = $self->{OPM_chapter}
+        or error __x"section '{name}' outside chapter in {file} line {line}", name => $line, file => $fn, line => $ln;
 
-    my $section = $self->{OPM_section} = OODoc::Text::Section->new
-     ( name     => $line
-     , chapter  => $chapter
-     , linenr   => $ln
-     );
+    my $section = $self->{OPM_section} =
+        OODoc::Text::Section->new(name => $line, chapter => $chapter, linenr => $ln);
 
     $chapter->section($section);
     $self->setBlock($section->openDescription);
@@ -369,15 +339,11 @@ sub docSubSection($$$$)
 
     $self->closeSubSection;
 
-    my $section = $self->{OPM_section};
-    defined $section
-        or die "ERROR: subsection `$line' outside section in $fn line $ln\n";
+    my $section = $self->{OPM_section}
+        or error __x"subsection '{name}' outside section in {file} line {line}", name => $line, file => $fn, line => $ln;
 
-    my $subsection = $self->{OPM_subsection} = OODoc::Text::SubSection->new
-     ( name     => $line
-     , section  => $section
-     , linenr   => $ln
-     );
+    my $subsection = $self->{OPM_subsection} =
+        OODoc::Text::SubSection->new(name => $line, section => $section, linenr => $ln);
 
     $section->subsection($subsection);
     $self->setBlock($subsection->openDescription);
@@ -387,10 +353,9 @@ sub docSubSection($$$$)
 sub closeSubSection()
 {   my $self       = shift;
     my $subsection = delete $self->{OPM_subsection};
-    $self;
+    $self->closeSubSubSection;
 }
 
-
 #-------------------------------------------
 # SUBSECTION
 
@@ -402,16 +367,11 @@ sub docSubSubSection($$$$)
 
     $self->closeSubSubSection;
 
-    my $subsection = $self->{OPM_subsection};
-    defined $subsection
-     or die "ERROR: subsubsection `$line' outside subsection in $fn line $ln\n";
+    my $subsection = $self->{OPM_subsection}
+        or error __x"subsubsection '{name}' outside section in {file} line {line}", name => $line, file => $fn, line => $ln;
 
-    my $subsubsection
-      = $self->{OPM_subsubsection} = OODoc::Text::SubSubSection->new
-      ( name       => $line
-      , subsection => $subsection
-      , linenr     => $ln
-      );
+    my $subsubsection = $self->{OPM_subsubsection} =
+        OODoc::Text::SubSubSection->new(name => $line, subsection => $subsection, linenr => $ln);
 
     $subsection->subsubsection($subsubsection);
     $self->setBlock($subsubsection->openDescription);
@@ -421,7 +381,7 @@ sub docSubSubSection($$$$)
 sub closeSubSubSection()
 {   my $self = shift;
     delete $self->{OPM_subsubsection};
-    $self;
+    $self->closeSubroutine;
 }
 
 #-------------------------------------------
@@ -436,24 +396,15 @@ sub docSubroutine($$$$)
     my $type = $1;
 
     my ($name, $params)
-             = $type eq 'overload' ? ($line, '')
-             :                       $line =~ m/^(\w*)\s*(.*?)\s*$/;
+     = $type eq 'overload' ? ($line, '')
+     :                       $line =~ m/^(\w*)\s*(.*?)\s*$/;
 
-    my $container = $self->{OPM_subsection}
-                 || $self->{OPM_section}
-	         || $self->{OPM_chapter};
-
-    die "ERROR: subroutine $name outside chapter in $fn line $ln\n"
-       unless defined $container;
+    my $container = $self->{OPM_subsection} || $self->{OPM_section} || $self->{OPM_chapter}
+        or error __x"subroutine {name} outside chapter in {file} line {line}", name => $name, file => $fn, line => $ln;
 
     $type    = 'i_method' if $type eq 'method';
-    my $sub  = $self->{OPM_subroutine} = OODoc::Text::Subroutine->new
-     ( type       => $type
-     , name       => $name
-     , parameters => $params
-     , linenr     => $ln
-     , container  => $container
-     );
+    my $sub  = $self->{OPM_subroutine} =
+       OODoc::Text::Subroutine->new(type => $type, name => $name, parameters => $params, linenr => $ln, container => $container);
 
     $self->setBlock($sub->openDescription);
     $container->addSubroutine($sub);
@@ -474,21 +425,20 @@ sub docOption($$$$)
 {   my ($self, $match, $line, $fn, $ln) = @_;
 
     unless($line =~ m/^\=option\s+(\S+)\s+(.+?)\s*$/ )
-    {   warn "WARNING: option line incorrect in $fn line $ln:\n$line";
+    {   warning __x"option line incorrect in {file} line {linenr}:\n {line}", file => $fn, linenr => $ln, line => $line;
         return;
     }
     my ($name, $parameters) = ($1, $2);
 
-    my $sub  = $self->{OPM_subroutine};
-    die "ERROR: option $name outside subroutine in $fn line $ln\n"
-       unless defined $sub;
+    my $sub  = $self->{OPM_subroutine}
+        or error __x"option {name} outside subroutine in {file} line {line}", name => $name, file => $fn, line => $ln;
 
     my $option  = OODoc::Text::Option->new
-     ( name       => $name
-     , parameters => $parameters
-     , linenr     => $ln
-     , subroutine => $sub
-     );
+      ( name       => $name
+      , parameters => $parameters
+      , linenr     => $ln
+      , subroutine => $sub
+      );
 
     $self->setBlock($option->openDescription);
     $sub->option($option);
@@ -496,28 +446,23 @@ sub docOption($$$$)
 }
 
 #-------------------------------------------
+# DEFAULT
 
 
 sub docDefault($$$$)
 {   my ($self, $match, $line, $fn, $ln) = @_;
 
     unless($line =~ m/^\=default\s+(\S+)\s+(.+?)\s*$/ )
-    {   warn "WARNING: default line incorrect in $fn line $ln:\n$line";
+    {   warning __x"default line incorrect in {file} line {linenr}:\n {line}", file => $fn, linenr => $ln, line => $line;
         return;
     }
 
     my ($name, $value) = ($1, $2);
 
-    my $sub  = $self->{OPM_subroutine};
-    die "ERROR: default for option $name outside subroutine in $fn line $ln\n"
-       unless defined $sub;
+    my $sub = $self->{OPM_subroutine}
+       or error __x"default for option {name} outside subroutine in {file} line {line}", name => $name, file => $fn, line => $ln;
 
-    my $default  = OODoc::Text::Default->new
-     ( name       => $name
-     , value      => $value
-     , linenr     => $ln
-     , subroutine => $sub
-     );
+    my $default = OODoc::Text::Default->new(name => $name, value => $value, linenr => $ln, subroutine => $sub);
 
     $sub->default($default);
     $sub;
@@ -527,7 +472,7 @@ sub docRequires($$$$)
 {   my ($self, $match, $line, $fn, $ln) = @_;
 
     unless($line =~ m/^\=requires\s+(\w+)\s+(.+?)\s*$/ )
-    {   warn "WARNING: requires line incorrect in $fn line $ln:\n$line";
+    {   warning __x"requires line incorrect in {file} line {linenr}:\n {line}", file => $fn, linenr => $ln, line => $line;
         return;
     }
 
@@ -548,20 +493,14 @@ sub docDiagnostic($$$$)
 
     $line =~ s/\s*$//;
     unless(length $line)
-    {   warn "WARNING: no diagnostic message supplied in $fn line $ln";
+    {   warning __x"no diagnostic message supplied in {file} line {line}", file => $fn, line => $ln;
         return;
     }
 
-    my $sub  = $self->{OPM_subroutine};
-    die "ERROR: diagnostic $type outside subroutine in $fn line $ln\n"
-       unless defined $sub;
+    my $sub  = $self->{OPM_subroutine}
+        or error __x"diagnostic {type} outside subroutine in {file} line {line}", type => $type, file => $fn, line => $ln;
 
-    my $diag  = OODoc::Text::Diagnostic->new
-     ( type       => ucfirst($type)
-     , name       => $line
-     , linenr     => $ln
-     , subroutine => $sub
-     );
+    my $diag  = OODoc::Text::Diagnostic->new(type => ucfirst($type), name => $line, linenr => $ln, subroutine => $sub);
 
     $self->setBlock($diag->openDescription);
     $sub->diagnostic($diag);
@@ -584,57 +523,46 @@ sub docExample($$$$)
                  || $self->{OPM_section}
                  || $self->{OPM_chapter};
 
-    die "ERROR: example outside chapter in $fn line $ln\n"
-       unless defined $container;
+    defined $container
+        or error __x"example outside chapter in {file} line {line}", file => $fn, line => $ln;
 
-    my $example  = OODoc::Text::Example->new
-     ( name      => ($line || '')
-     , linenr    => $ln
-     , container => $container
-     );
+    my $example  = OODoc::Text::Example->new(name => ($line || ''), linenr => $ln, container => $container);
 
     $self->setBlock($example->openDescription);
     $container->example($example);
     $example;
 }
 
-#-------------------------------------------
-
 
 sub debugRemains($$$$)
 {   my ($self, $match, $line, $fn, $ln) = @_;
 
-    warn "WARNING: Debugging remains in $fn line $ln\n"
-       unless $self->inDoc || $self->currentManual->isPurePod;
+    $self->inDoc || $self->currentManual->isPurePod
+        or warning __x"Debugging remains in {file} line {line}", file => $fn, line => $ln;
 
     undef;
 }
 
-#-------------------------------------------
-
 
 sub forgotCut($$$$)
 {   my ($self, $match, $line, $fn, $ln) = @_;
 
-    warn "WARNING: You may have accidentally captured code in doc $fn line $ln\n"
-       if $self->inDoc && ! $self->currentManual->isPurePod;
+    $self->inDoc && ! $self->currentManual->isPurePod
+        and warning __x"You may have accidentally captured code in doc {file} line {line}", file => $fn, line => $ln;
 
     undef;
 }
 
 #-------------------------------------------
 
-
 sub decomposeM($$)
 {   my ($self, $manual, $link) = @_;
 
-    my ($subroutine, $option)
-      = $link =~ s/(?:^|\:\:) (\w+) \( (.*?) \)$//x ? ($1, $2)
-      :                                               ('', '');
+    my ($subroutine, $option) = $link =~ s/(?:^|\:\:) (\w+) \( (.*?) \)$//x ? ($1, $2) : ('', '');
 
     my $man;
        if(not length($link)) { $man = $manual }
-    elsif(defined($man = $self->manual($link))) { ; }
+    elsif(defined($man = $self->findManual($link))) { ; }
     else
     {   eval "no warnings; require $link";
         if(  ! $@
@@ -642,12 +570,11 @@ sub decomposeM($$)
           || $self->skipManualLink($link)
           ) { ; }
         elsif($@ =~ m/Can't locate/ )
-        {  warn "WARNING: module $link is not on your system, found in $manual\n";
+        {   warning __x"module {name} is not on your system, found in {manual}", name => $link, manual => $manual;
         }
         else
         {  $@ =~ s/ at \(eval.*//;
-           warn "WARNING: use problem for module $link in $manual;\n$@";
-           warn " Did you use an 'M' tag on something which is not a module?\n";
+           warning __x"use problem for module {name} in {manual};\n{err}", name => $link, manual => $manual, err => $@;
         }
         $man = $link;
     }
@@ -660,29 +587,31 @@ sub decomposeM($$)
                );
     }
 
-    return (undef, $man)
-        unless defined $subroutine && length $subroutine;
+    defined $subroutine && length $subroutine
+        or return (undef, $man);
 
-    my $package = $self->manual($man->package);
+    my $package = $self->findManual($man->package);
     unless(defined $package)
     {   my $want = $man->package;
-        warn "WARNING: no manual for $want (correct casing?)\n";
+        warning __x"no manual for {package} (correct casing?)", package => $want;
         return (undef, "$want subroutine $subroutine");
     }
 
     my $sub     = $package->subroutine($subroutine);
     unless(defined $sub)
-    {   warn "WARNING: subroutine $subroutine() is not defined by $package, but linked to in $manual\n";
+    {   warning __x"subroutine {call}() is not defined by {pkg}, but linked to in {manual}",
+            call => $subroutine, pkg => $package, manual => $manual;
         return ($package, "$package subroutine $subroutine");
     }
 
     my $location = $sub->manual;
-    return ($location, $sub)
-        unless defined $option && length $option;
+    defined $option && length $option
+        or return ($location, $sub);
 
     my $opt = $sub->findOption($option);
     unless(defined $opt)
-    {   warn "WARNING: option \"$option\" unknown for $subroutine() in $location, found in $manual\n";
+    {   warning __x"option '{name}' unknown for {call}() in {where}, found in {manual}",
+            name => $option, call => $subroutine, where => $location, manual => $manual;
         return ($location, "$package subroutine $subroutine option $option");
     }
 
@@ -692,30 +621,26 @@ sub decomposeM($$)
 
 sub decomposeL($$)
 {   my ($self, $manual, $link) = @_;
-    my $text = $link =~ s/^([^|]*)\|// ? $1 : undef;
+    my $text  = $link =~ s/^([^|]*)\|// ? $1 : undef;
 
-    unless(length $link)
-    {   warn "WARNING: empty L link in $manual";
-        return ();
-    }
+    length $link
+        or (warning __x"empty L link in {manual}", manual => $manual), return ();
 
-    if($link  =~ m/^[a-z]+\:[^:]/ )
-    {   $text         = $link unless defined $text;
-        return (undef, undef, $link, $text);
-    }
+    return (undef, undef, $link, $text // $link)
+        if $link  =~ m/^[a-z]+\:[^:]/;
 
     my ($name, $item) = $link =~ m[(.*?)(?:/(.*))?$];
 
     ($name, $item)    = (undef, $name) if $name =~ m/^".*"$/;
     $item     =~ s/^"(.*)"$/$1/        if defined $item;
 
-    my $man   = length $name ? ($self->manual($name) || $name) : $manual;
+    my $man   = length $name ? ($self->findManual($name) || $name) : $manual;
 
     my $dest;
     if(!ref $man)
     {   unless(defined $text && length $text)
-        {  $text = "manual $man";
-           $text .= " entry $item" if defined $item && length $item;
+        {   $text  = "manual $man";
+            $text .= " entry $item" if defined $item && length $item;
         }
 
         if($man !~ m/\(\d.*\)\s*$/)
@@ -724,26 +649,26 @@ sub decomposeL($$)
         }
     }
     elsif(!defined $item)
-    {   $dest  = $man;
-        $text  = $man->name unless defined $text;
+    {   $dest   = $man;
+        $text //= $man->name;
     }
     elsif(my @obj = $man->all(findEntry => $item))
-    {   $dest  = shift @obj;
-        $text  = $item unless defined $text;
+    {   $dest   = shift @obj;
+        $text //= $item;
     }
     else
-    {   warn "WARNING: Manual $manual links to unknown entry \"$item\" in $man\n";
-        $dest = $man;
-        $text = "$man" unless defined $text;
+    {   warning __x"manual {manual} links to unknown entry '{item}' in {other_manual}",
+            manual => $manual, entry => $item, other_manual => $man;
+        $dest   = $man;
+        $text //= "$man";
     }
 
     ($man, $dest, undef, $text);
 }
 
-
 sub cleanupPod($$$)
-{   my ($self, $formatter, $manual, $string) = @_;
-    return '' unless defined $string && length $string;
+{   my ($self, $manual, $string, %args) = @_;
+    defined $string && length $string or return '';
 
     my @lines   = split /^/, $string;
     my $protect;
@@ -752,18 +677,13 @@ sub cleanupPod($$$)
     {   $protect = $1  if $lines[$i] =~ m/^=(for|begin)\s+\w/;
 
         undef $protect if $lines[$i] =~ m/^=end/;
-
-        undef $protect if $lines[$i] =~ m/^\s*$/
-                       && $protect && $protect eq 'for';
-
+        undef $protect if $lines[$i] =~ m/^\s*$/ && $protect && $protect eq 'for';
         next if $protect;
 
-        $lines[$i] =~
-             s/\bM\<([^>]*)\>/$self->cleanupPodM($formatter,$manual,$1)/ge;
+        $lines[$i] =~ s/\bM\<([^>]*)\>/$self->cleanupPodM($manual, $1, \%args)/ge;
 
-        $lines[$i] =~
-             s/\bL\<([^>]*)\>/$self->cleanupPodL($formatter,$manual,$1)/ge
-                if substr($lines[$i], 0, 1) eq ' ';
+        $lines[$i] =~ s/\bL\<([^>]*)\>/$self->cleanupPodL($manual, $1, \%args)/ge
+            if substr($lines[$i], 0, 1) eq ' ';
 
         # permit losing blank lines around pod statements.
         if(substr($lines[$i], 0, 1) eq '=')
@@ -771,8 +691,7 @@ sub cleanupPod($$$)
             {   splice @lines, $i-1, 0, "\n";
                 $i++;
             }
-            elsif($i < $#lines && $lines[$i+1] ne "\n"
-                  && substr($lines[$i], 0, 5) ne "=for ")
+            elsif($i < $#lines && $lines[$i+1] ne "\n" && substr($lines[$i], 0, 5) ne "=for ")
             {   splice @lines, $i+1, 0, "\n";
             }
         }
@@ -795,24 +714,23 @@ sub cleanupPod($$$)
 
 
 sub cleanupPodM($$$)
-{   my ($self, $formatter, $manual, $link) = @_;
+{   my ($self, $manual, $link, $args) = @_;
     my ($toman, $to) = $self->decomposeM($manual, $link);
-    ref $to ? $formatter->link($toman, $to, $link) : $to;
+    ref $to ? $args->{create_link}->($toman, $to, $link, $args) : $to;
 }
 
 
 sub cleanupPodL($$$)
-{   my ($self, $formatter, $manual, $link) = @_;
+{   my ($self, $manual, $link, $args) = @_;
     my ($toman, $to, $href, $text) = $self->decomposeL($manual, $link);
     $text;
 }
 
-#-------------------------------------------
+sub cleanupHtml($$$)
+{   my ($self, $manual, $string, %args) = @_;
+    defined $string && length $string or return '';
 
-
-sub cleanupHtml($$$;$)
-{   my ($self, $formatter, $manual, $string, $is_html) = @_;
-    return '' unless defined $string && length $string;
+	my $is_html = $args{is_html};
 
     if($string =~ m/(?:\A|\n)                   # start of line
                     \=begin\s+(:?\w+)\s*        # begin statement
@@ -826,39 +744,32 @@ sub cleanupHtml($$$;$)
                     /xs
       )
     {   my ($before, $type, $capture, $after) = ($`, lc($1), $2, $');
-        if($type =~ m/^\:(text|pod)\b/ )
-        {   $type    = 'text';
-            $capture = $self->cleanupPod($formatter, $manual, $capture);
-        }
-        elsif($type =~ m/^\:?html\b/ )
+        if($type =~ m/^\:?html\b/ )
         {   $type    = 'html';
-            $capture = $self->cleanupHtml($formatter, $manual, $capture, 1);
+            $capture = $self->cleanupHtml($manual, $capture, is_html => 1);
         }
 
-        my $take = $type eq 'text' ? "<pre>\n". $capture . "</pre>\n"
-                 : $type eq 'html' ? $capture
-                 :                   '';   # ignore
-
-        return $self->cleanupHtml($formatter, $manual, $before)
-             . $take
-             . $self->cleanupHtml($formatter, $manual, $after);
+        return $self->cleanupHtml($manual, $before)
+             . $capture
+             . $self->cleanupHtml($manual, $after);
     }
 
     for($string)
     {   unless($is_html)
         {   s#\&#\&amp;#g;
-            s#(?<!\b[LFCIBEM])\<#&lt;#g;
-            s#\-\>#-\&gt;#g;
+            s#(\s|^)\<([^>]+)\>#$1&lt;$2&gt;#g;
+            s#(?<!\b[LFCIBEMX])\<#&lt;#g;
+            s#([=-])\>#$1\&gt;#g;
         }
-        s/\bM\<([^>]*)\>/$self->cleanupHtmlM($formatter, $manual, $1)/ge;
-        s/\bL\<([^>]*)\>/$self->cleanupHtmlL($formatter, $manual, $1)/ge;
-        s#\bC\<([^>]*)\>#<code>$1</code>#g;
+        s/\bM\<([^>]*)\>/$self->cleanupHtmlM($manual, $1, \%args)/ge;
+        s/\bL\<([^>]*)\>/$self->cleanupHtmlL($manual, $1, \%args)/ge;
         s#\bI\<([^>]*)\>#<em>$1</em>#g;
         s#\bB\<([^>]*)\>#<b>$1</b>#g;
         s#\bE\<([^>]*)\>#\&$1;#g;
         s#^\=over\s+\d+\s*#\n<ul>\n#gms;
-        s#(?:\A|\n)\=item\s*(?:\*\s*)?([^\n]*)#\n<li><b>$1</b><br />#gms;
+        s#(?:\A|\n)\=item\s*(?:\*\s*)?([^\n]*)#\n<li>$1<br />#gms;
         s#(?:\A|\s*)\=back\b#\n</ul>#gms;
+        s#\bC\<([^>]*)\>#<code>$1</code>#g;  # introduces a '<', hence last
         s#^=pod\b##gm;
 
         # when F<> contains a URL, it will be used. However, when it
@@ -895,23 +806,22 @@ sub cleanupHtml($$$;$)
 
 
 sub cleanupHtmlM($$$)
-{   my ($self, $formatter, $manual, $link) = @_;
+{   my ($self, $manual, $link, $args) = @_;
     my ($toman, $to) = $self->decomposeM($manual, $link);
-    ref $to ? $formatter->link($toman, $to, $link) : $to;
+    ref $to ? $args->{create_link}->($toman, $to, $link, $args) : $to;
 }
 
 
 sub cleanupHtmlL($$$)
-{   my ($self, $formatter, $manual, $link) = @_;
+{   my ($self, $manual, $link, $args) = @_;
     my ($toman, $to, $href, $text) = $self->decomposeL($manual, $link);
 
      defined $href ? qq[<a href="$href" target="_blank">$text</a>]
    : !defined $to  ? $text
-   : ref $to       ? $formatter->link($toman, $to, $text)
+   : ref $to       ? $args->{create_link}->($toman, $to, $text, $args)
    :                 qq[<a href="$to">$text</a>]
 }
 
 #-------------------------------------------
 
-
 1;
