@@ -1,21 +1,25 @@
-# Copyrights 2003-2021 by [Mark Overmeer].
-#  For other contributors see ChangeLog.
-# See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.02.
-# This code is part of perl distribution OODoc.  It is licensed under the
-# same terms as Perl itself: https://spdx.org/licenses/Artistic-2.0.html
+# This code is part of Perl distribution OODoc version 3.00.
+# The POD got stripped from this file by OODoc version 3.00.
+# For contributors see file ChangeLog.
 
-package OODoc::Text::Chapter;
-use vars '$VERSION';
-$VERSION = '2.02';
+# This software is copyright (c) 2003-2025 by Mark Overmeer.
 
-use base 'OODoc::Text::Structure';
+# This is free software; you can redistribute it and/or modify it under
+# the same terms as the Perl 5 programming language system itself.
+# SPDX-License-Identifier: Artistic-1.0-Perl OR GPL-1.0-or-later
+
+package OODoc::Text::Chapter;{
+our $VERSION = '3.00';
+}
+
+use parent 'OODoc::Text::Structure';
 
 use strict;
 use warnings;
 
 use Log::Report    'oodoc';
-use List::Util     'first';
+
+use List::Util     qw/first/;
 
 
 sub init($)
@@ -23,12 +27,8 @@ sub init($)
     $args->{type}       ||= 'Chapter';
     $args->{container}  ||= delete $args->{manual} or panic;
     $args->{level}      ||= 1;
-
-    $self->SUPER::init($args)
-        or return;
-
+    $self->SUPER::init($args) or return;
     $self->{OTC_sections} = [];
-
     $self;
 }
 
@@ -40,8 +40,8 @@ sub emptyExtension($)
     $empty;
 }
 
-sub manual() {shift->container}
-sub path()   {shift->name}
+sub manual() { $_[0]->container }
+sub path()   { $_[0]->name }
 
 sub findSubroutine($)
 {   my ($self, $name) = @_;
@@ -70,9 +70,12 @@ sub findEntry($)
 
 sub all($@)
 {   my $self = shift;
-    ($self->SUPER::all(@_), map {$_->all(@_)} $self->sections);
+      ( $self->SUPER::all(@_)
+      , map $_->all(@_), $self->sections
+      );
 }
 
+#-------------------
 
 sub section($)
 {   my ($self, $thing) = @_;
@@ -82,7 +85,7 @@ sub section($)
         return $thing;
     }
 
-    first {$_->name eq $thing} $self->sections;
+    first { $_->name eq $thing } $self->sections;
 }
 
 
@@ -95,4 +98,6 @@ sub sections()
    @{$self->{OTC_sections}};
 }
 
+*nest = \*sections;
+
 1;
