@@ -1,15 +1,18 @@
-# Copyrights 2003-2021 by [Mark Overmeer].
-#  For other contributors see ChangeLog.
-# See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.02.
-# This code is part of perl distribution OODoc.  It is licensed under the
-# same terms as Perl itself: https://spdx.org/licenses/Artistic-2.0.html
+# This code is part of Perl distribution OODoc version 3.00.
+# The POD got stripped from this file by OODoc version 3.00.
+# For contributors see file ChangeLog.
 
-package OODoc::Text::Structure;
-use vars '$VERSION';
-$VERSION = '2.02';
+# This software is copyright (c) 2003-2025 by Mark Overmeer.
 
-use base 'OODoc::Text';
+# This is free software; you can redistribute it and/or modify it under
+# the same terms as the Perl 5 programming language system itself.
+# SPDX-License-Identifier: Artistic-1.0-Perl OR GPL-1.0-or-later
+
+package OODoc::Text::Structure;{
+our $VERSION = '3.00';
+}
+
+use parent 'OODoc::Text';
 
 use strict;
 use warnings;
@@ -43,7 +46,6 @@ sub emptyExtension($)
 
 #-------------------------------------------
 
-
 sub level()   {shift->{OTS_level}}
 
 
@@ -54,7 +56,6 @@ sub niceName()
 
 #-------------------------------------------
 
-
 sub path() { panic "Not implemented" }
 
 
@@ -62,7 +63,6 @@ sub findEntry($) { panic "Not implemented" }
 
 #-------------------------------------------
 
-
 sub all($@)
 {   my ($self, $method) = (shift, shift);
     $self->$method(@_);
@@ -74,7 +74,7 @@ sub isEmpty()
 
     my $manual = $self->manual;
     return 0 if $self->description !~ m/^\s*$/;
-    return 0 if first {!$manual->inherited($_)}
+    return 0 if first { !$manual->inherited($_) }
         $self->examples, $self->subroutines;
 
     my @nested
@@ -83,16 +83,40 @@ sub isEmpty()
       : $self->isa('OODoc::Text::SubSection') ? $self->subsubsections
       : return 1;
 
-    not first {!$_->isEmpty} @nested;
+    not first { !$_->isEmpty } @nested;
+}
+
+sub publish($$)
+{   my ($self, $args) = @_;
+	my $p = $self->SUPER::publish($args);
+    $p->{level} = $self->level;
+    $p->{path}  = $self->path;
+
+	my @n = map $_->publish($args)->{id}, $self->nest;
+	$p->{nest} = \@n if @n;
+
+    my @s = map $_->publish($args)->{id}, $self->subroutines;
+    $p->{subroutines} = \@s if @s;
+    $p;
 }
 
 #-------------------
 
 sub addSubroutine(@)
-{  my $self = shift;
-   push @{$self->{OTS_subs}}, @_;
-   $_->container($self) for @_;
-   $self;
+{   my $self = shift;
+    my $subs = $self->{OTS_subs} ||= [];
+
+    foreach my $sub (@_)
+    {   $sub->container($self);
+
+        my $name = $sub->name;
+        if(my $has = first { $_->name eq $name } @$subs)
+		{   warn "WARNING: name '$name' seen before, lines ".$has->linenr. " and " . $sub->linenr . "\n";
+        }
+        push @{$self->{OTS_subs}}, $sub;
+    }
+
+    $self;
 }
 
 
@@ -113,5 +137,4 @@ sub setSubroutines($)
 #-------------------------------------------
 
 
-
 1;
